#ifndef __CALENDAR_WIDGET_H__
#define __CALENDAR_WIDGET_H__

/* Main Calendar Widget
 * Copyright (C) 2002  Sebastian Rittau <srittau@jroger.in-berlin.de>
 *
 * $Id: calendar-widget.h,v 1.1.2.2 2002/05/27 18:22:54 srittau Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/* This class provides a widget that contains a complete month view.
 * It's derived from GnomeCanvas and makes use of CalendarMonthItem.
 */

#include <time.h>

#include <glib.h>

#include <gtk/gtkbox.h>


#define CALENDAR_TYPE_WIDGET		(calendar_widget_get_type())
#define CALENDAR_WIDGET(obj)		(GTK_CHECK_CAST ((obj), CALENDAR_TYPE_WIDGET, CalendarWidget))
#define CALENDAR_WIDGET_CLASS(klass)	(GTK_CHECK_CLASS_CAST ((klass), CALENDAR_TYPE_WIDGET))
#define CALENDAR_IS_WIDGET(obj)		(GTK_CHECK_TYPE ((obj), CALENDAR_TYPE_WIDGET))
#define CALENDAR_IS_WIDGET_CLASS(klass)	(GTK_CHECK_CLASS_TYPE ((klass), CALENDAR_TYPE_WIDGET))

typedef struct _CalendarWidget		CalendarWidget;
typedef struct _CalendarWidgetClass	CalendarWidgetClass;
typedef struct _CalendarWidgetPriv	CalendarWidgetPriv;

struct _CalendarWidget
{
	GtkVBox parent;

	CalendarWidgetPriv *priv;
};

struct _CalendarWidgetClass
{
	GtkVBoxClass parent_class;
};

GType		 calendar_widget_get_type	(void);
GtkWidget	*calendar_widget_new		(void);

gboolean	 calendar_widget_save		(CalendarWidget *widget,
						 const gchar *file);

void		 calendar_widget_next		(CalendarWidget *widget);
void		 calendar_widget_previous	(CalendarWidget *widget);
void		 calendar_widget_today		(CalendarWidget *widget);
void		 calendar_widget_goto		(CalendarWidget *widget,
						 struct tm *tm);

gboolean	 calendar_widget_set_calendar		(CalendarWidget *widget, const gchar *filename, GError **error);
gboolean	 calendar_widget_set_calendar_default	(CalendarWidget *widget, GError **error);
void		 calendar_widget_set_calendar_new	(CalendarWidget *widget);
gboolean	 calendar_widget_save_calendar		(CalendarWidget *widget, GError **error);

/* FIXME: obsolete */
#include "gnome-cal.h"
GnomeCalendar	*calendar_widget_get_gncal		(CalendarWidget *widget);

#endif /* __CALENDAR_WIDGET_H__ */
