#ifndef __ICAL_COMPONENT_H__
#define __ICAL_COMPONENT_H__

/* Generic ICalendar Object
 * Copyright (C) 2002  Sebastian Rittau <srittau@jroger.in-berlin.de>
 *
 * $Id: ical-component.h,v 1.1.2.1 2002/04/18 17:57:09 srittau Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <glib-object.h>

#include "calobj.h"


/* Possible values for the status property. */

typedef enum {
	ICAL_EVENT_TENTATIVE	= 1,
	ICAL_EVENT_CONFIRMED	= 2,
	ICAL_EVENT_CANCELLED	= 3,
	ICAL_TODO_NEEDS_ACTION	= 4,
	ICAL_TODO_COMPLETED	= 5,
	ICAL_TODO_IN_PROCESS	= 6,
	ICAL_TODO_CANCELLED	= ICAL_EVENT_CANCELLED,
	ICAL_JOURNAL_DRAFT	= 7,
	ICAL_JOURNAL_FINAL	= 8,
	ICAL_JOURNAL_CANCELLED	= ICAL_EVENT_CANCELLED
} ICalStatus;


/* Properties of the ICalComponent class:
 *
 * name          | type         | default      | description
 * --------------+--------------+--------------+-----------------------------
 * categories    | GList *      | NULL         | Categories
 * class         | string       | NULL         | Classification
 * description   | string       | NULL         | Description
 * priority      | guint        | 5            | Priority
 * status        | enum         | none         | Status (s.a.)
 * summary       | string       | NULL         | Summary
 *
 * dtend         | struct tm *  | NULL         | Date/Time End
 * due           | struct tm *  | NULL         | Date/Time Due
 * dtstart       | struct tm *  | NULL         | Date/Time Start
 * transp        | gboolean     | FALSE        | Time Transparency
 *
 * organizer     | string       | NULL         | Organizer
 * uid           | string       | NULL         | Unique Identifier
 *
 * created       | struct tm *  | NULL         | Date/Time Created
 * dtstamp       | struct tm *  | NULL         | Date/Time Stamp
 * last-modified | struct tm *  | NULL         | Last Modified
 * sequence      | gint32       | 0            | Sequence number
 */

#define ICAL_TYPE_COMPONENT		(ical_component_get_type())
#define ICAL_COMPONENT(obj)		(G_TYPE_CHECK_INSTANCE_CAST ((obj), ICAL_TYPE_COMPONENT, ICalComponent))
#define ICAL_COMPONENT_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), ICAL_TYPE_COMPONENT))
#define ICAL_IS_COMPONENT(obj)		(G_TYPE_CHECK_INSTANCE_TYPE ((obj), ICAL_TYPE_COMPONENT))
#define ICAL_IS_COMPONENT_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE ((klass), ICAL_TYPE_COMPONENT))

typedef struct _ICalComponent		ICalComponent;
typedef struct _ICalComponentClass	ICalComponentClass;
typedef struct _ICalComponentPriv	ICalComponentPriv;

struct _ICalComponent
{
	GObject parent;

	ICalComponentPriv *priv;
};

struct _ICalComponentClass
{
	GObjectClass parent_class;

        void (* changed) (ICalComponent *item);
};

GType		 ical_component_get_type		(void);

/* The next function can be used to set certain default values for
 * newly created objects.
 */
void		 ical_component_set_fresh_uid		(ICalComponent *ical);
void		 ical_component_set_fresh_created	(ICalComponent *ical);
void		 ical_component_set_fresh_dtstamp	(ICalComponent *ical);
void		 ical_component_set_default_organizer	(ICalComponent *ical);

/* FIXME: backwards compatibility methods */
void		 ical_component_set_from_calobj	(ICalComponent	*item,
						 iCalObject	*calobj);
iCalObject	*ical_component_get_calobj	(ICalComponent	*item);


/* To be freed by caller. */
gchar		*ical_component_get_categories_as_string (ICalComponent *item);


#endif /* __ICAL_COMPONENT_H__ */
