/* ICalendar To Do Object
 * Copyright (C) 2002  Sebastian Rittau <srittau@jroger.in-berlin.de>
 *
 * $Id: ical-todo.c,v 1.1.2.2 2002/04/18 18:08:28 srittau Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <glib.h>

#include "ical-todo.h"


enum {
	ARG_CATEGORIES = 1
};

struct _ICalTodoPriv {
	GList *categories;
};


static void ical_todo_class_init	(ICalTodoClass *klass);
static void ical_todo_init		(ICalTodo *item);
static void ical_todo_finalize		(GObject *object);


static ICalComponentClass *parent_class;


GType
ical_todo_get_type (void)
{
	static GType ical_todo_type = 0;

	if (!ical_todo_type) {
		static const GTypeInfo ical_todo_info = {
			sizeof (ICalTodoClass),
			NULL, /* base_init */
			NULL, /* base_finalize */
			(GClassInitFunc) ical_todo_class_init,
			NULL, /* class_finalize */
			NULL, /* class_data */
			sizeof (ICalTodo),
			5,    /* n_preallocs */
			(GInstanceInitFunc) ical_todo_init,
		};

		ical_todo_type = g_type_register_static (ICAL_TYPE_COMPONENT,
							 "ICalTodo",
							 &ical_todo_info,
							 0);
	}

	return ical_todo_type;
}

static void
ical_todo_class_init (ICalTodoClass *klass)
{
        GObjectClass *object_class;

        object_class = G_OBJECT_CLASS (klass);

        parent_class = g_type_class_peek_parent (klass);

        object_class->finalize     = ical_todo_finalize;
}

static void
ical_todo_init (ICalTodo *item)
{
	g_return_if_fail (item != NULL);
	g_return_if_fail (ICAL_IS_TODO (item));

	item->priv = g_new0 (ICalTodoPriv, 1);
}

static void
ical_todo_finalize (GObject *object)
{
	ICalTodo *item;

	g_return_if_fail (object != NULL);
	g_return_if_fail (ICAL_IS_TODO (object));

	item = ICAL_TODO (object);

	if (item->priv) {
		g_free (item->priv);
		item->priv = NULL;
	}

	G_OBJECT_CLASS (parent_class)->finalize (object);
}

ICalTodo *
ical_todo_new (void)
{
	ICalTodo *item;

	item = g_object_new (ICAL_TYPE_TODO, NULL);

	return item;
}

ICalTodo *
ical_todo_new_from_calobj (iCalObject *calobj)
{
	ICalTodo *item;

	g_return_val_if_fail (calobj != NULL, NULL);

	item = ical_todo_new ();

	ical_component_set_from_calobj (ICAL_COMPONENT (item), calobj);

	return item;
}

void
ical_todo_set_fresh (ICalTodo *todo)
{
	g_return_if_fail (todo != NULL);
	g_return_if_fail (ICAL_IS_TODO (todo));

	ical_component_set_fresh_uid (ICAL_COMPONENT (todo));
	ical_component_set_fresh_created (ICAL_COMPONENT (todo));
	ical_component_set_fresh_dtstamp (ICAL_COMPONENT (todo));
}
