/*
 * Main file for the GNOME Calendar program
 * Copyright (C) 1998 the Free Software Foundation
 *
 * Authors:
 *          Miguel de Icaza (miguel@kernel.org)
 *          Federico Mena (federico@nuclecu.unam.mx)
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <pwd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <string.h>
#include <ctype.h>
#include <time.h>
#include <errno.h>

#include <gconf/gconf.h>
#include <gconf/gconf-client.h>
#include <gnome.h>
#include <libbonobo.h>

#include "alarm.h"
#include "bonobo-calendar-factory.h"
#include "calendar.h"
#include "eventedit.h"
#include "gncal-day-panel.h"
#include "gnome-cal.h"
#include "gnomecal-config.h"
#include "timeutil.h"
#include "todo-list.h"
#include "utils-ui.h"


static void
my_save_calendar (GnomeCalendar *gcal, const gchar *filename)
{
	TodoList *todo;
	GList *list;

	/* Adjust to do items */

	todo = gncal_day_panel_get_todo_list (GNCAL_DAY_PANEL (gcal->day_view));

	list = todo_list_get_list (todo);

	calendar_set_todo_list (gcal->cal, list);

	g_list_free (list);

	calendar_save (gcal->cal, filename);
}

static void
save_response (GtkWidget *widget, gint response_id, GnomeCalendar *gcal)
{
	if (response_id == 1)
		my_save_calendar (gcal, gcal->cal->filename);

	gtk_widget_destroy (widget);
}
		
void
save_calendar (GnomeCalendar *gcal)
{
	struct stat s;
		
	g_return_if_fail (gcal->cal->filename != NULL);

		if (stat (gcal->cal->filename, &s) == -1) {
			if (errno == ENOENT)
				my_save_calendar (gcal, gcal->cal->filename);

			return;
		}

		if (s.st_mtime != gcal->cal->file_time){
			GtkWidget *box;

			box = gtk_message_dialog_new (NULL, 0,
						      GTK_MESSAGE_INFO,
						      GTK_BUTTONS_YES_NO,
						      _("File %s has changed since it was loaded.\nContinue?"),
						      gcal->cal->filename);
			gtk_dialog_set_default_response (GTK_DIALOG (box), 1);
			g_signal_connect (G_OBJECT (box), "response",
					  G_CALLBACK (save_response), gcal);
			gtk_widget_show (box);
		}
		
		my_save_calendar (gcal, gcal->cal->filename);
}

/*
 * Saves @gcal if it is the default calendar
 */
void
save_default_calendar (GnomeCalendar *gcal)
{
	if (!gcal->cal->filename)
		return;

	save_calendar (gcal);
}
