/* Miscellaneous UI Utility Functions
 * Copyright (C) 2002  Sebastian Rittau <srittau@jroger.in-berlin.de>
 *
 * $Id: utils-ui.c,v 1.1.2.4 2002/06/01 14:45:07 srittau Exp $
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#include <time.h>

#include <gconf/gconf.h>
#include <gconf/gconf-client.h>

#include <gnome.h>

#include "gnomecal-config.h"
#include "utils-ui.h"

/* Open the help file at a specific anchor. */
void
ui_show_help (GtkWindow *parent, const gchar *anchor)
{
	GError *error = NULL;

	if (!gnome_help_display ("gnomecal", anchor, &error)) {
		GtkWidget *win;

		win = gtk_message_dialog_new (parent,
					      0,
					      GTK_MESSAGE_ERROR,
					      GTK_BUTTONS_OK,
					      _("Could not display help: %s"),
					      error->message);
		g_signal_connect (G_OBJECT (win), "response",
				  G_CALLBACK (gtk_widget_destroy), NULL);
		gtk_widget_show (win);
		g_error_free (error);
	}
}

/* Create a geometry string from a Gtk+ window. */
gchar *
ui_gtk_window_get_geometry (GtkWindow *win)
{
    gint xpos, ypos, width, height;

    g_return_val_if_fail (win != NULL, NULL);
    g_return_val_if_fail (GTK_IS_WINDOW (win), NULL);

    gtk_window_get_position (win, &xpos, &ypos);
    gtk_window_get_size (win, &width, &height);

    return g_strdup_printf ("%dx%d+%d+%d", xpos, ypos, width, height);
}

/* GConf callback for GtkCalendar's */
static void
ui_gconf_gtk_calendar_updated (GConfClient *gconf,
			       guint        cnxn_id,
			       GConfEntry  *entry,
			       gpointer     data)
{
	GtkCalendar *calendar;
        GtkCalendarDisplayOptions flags;
        const gchar *key;
        gboolean value;

        g_return_if_fail (entry != NULL);
        g_return_if_fail (data != NULL);
        g_return_if_fail (GTK_IS_CALENDAR (data));

	calendar = GTK_CALENDAR (data);

        key   = gconf_entry_get_key (entry);
        value = gconf_value_get_bool (gconf_entry_get_value (entry));

        flags = calendar->display_flags;
        if (value)
                flags &= ~GTK_CALENDAR_WEEK_START_MONDAY;
        else
                flags |= GTK_CALENDAR_WEEK_START_MONDAY;
        gtk_calendar_display_options (calendar, flags);
}

/* GConf set-up for GtkCalendar's */
guint
ui_gconf_setup_gtk_calendar (GtkCalendar *calendar)
{
	GConfClient *gconf;
	GtkCalendarDisplayOptions flags;
	guint cnxn;

	g_return_val_if_fail (calendar != NULL, 0);
	g_return_val_if_fail (GTK_IS_CALENDAR (calendar), 0);

	gconf = gconf_client_get_default ();

	gconf_client_add_dir (gconf, CONFIG_GENERAL_DIR,
			      GCONF_CLIENT_PRELOAD_NONE, NULL);

	/* Set-up the calendar widget */

	flags = calendar->display_flags;
	if (gconf_client_get_bool (gconf, CONFIG_GENERAL_WEEK_START, NULL))
		flags &= ~GTK_CALENDAR_WEEK_START_MONDAY;
	else
		flags |= GTK_CALENDAR_WEEK_START_MONDAY;
	gtk_calendar_display_options (calendar, flags);

	/* Notification */

	cnxn = gconf_client_notify_add (gconf, CONFIG_GENERAL_WEEK_START,
					ui_gconf_gtk_calendar_updated, calendar,
					NULL, NULL);

	g_object_unref (G_OBJECT (gconf));

	return cnxn;
}

void
ui_gconf_shutdown_gtk_calendar (GtkCalendar *calendar, guint cnxn)
{
	GConfClient *gconf;

	gconf = gconf_client_get_default ();

	gconf_client_notify_remove (gconf, cnxn);

	g_object_unref (G_OBJECT (gconf));
}
